# autobio

A Python package.

## Installation

```bash
pip install autobio
```

### Development

```bash
git clone https://github.com/briney/autobio.git
cd autobio
pip install -e ".[dev]"
```

## Usage

```python
import autobio
```
